"""Goodman Spectroscopic Tools

"""
from __future__ import absolute_import
from .redspec import ReduceSpectroscopy, get_args
from .wavelength import WavelengthCalibration
